// Copyright (c) 2000-2002 David Muse
// See the COPYING file for more information.

#include <rudiments/environment.h>
#include <rudiments/rawbuffer.h>

#ifdef RUDIMENTS_HAVE_WINDOWS_H
	#include <windows.h>
#endif
#include <time.h>
#include <sys/types.h>
#include <rudiments/mutex.h>
